
# Type: same as


holds between two entities that are considered equivalent to each other

URI: [biolink:same_as](https://w3id.org/biolink/vocab/same_as)


## Domain and Range

[NamedThing](NamedThing.md) ->  <sub>0..*</sub> [NamedThing](NamedThing.md)

## Parents

 *  is_a: [related to](related_to.md)

## Children


## Used by

 * [NamedThing](NamedThing.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | owl:equivalentClass |
|  | | owl:sameAs |
|  | | skos:exactMatch |
|  | | WD:P2888 |
| **In Subsets:** | | translator_minimal |

